Installing Sumo — EPICS-sumo 4.5.1 documentation

# Installing Sumo

## Parts of sumo

Sumo consists of scripts, python modules, documentation and configuration files.

The distribution does not contain the configuration files since you have to adapt them to your development host. Examples of configuration files are shown further below.

Sumo is available as a debian or rpm package, as a tar.gz or wheel file and on pypi. The sections below describe all installation options.

Note that you have to configure sumo after installing it, see The sumo configuration file.

## Requirements

Sumo requires at least Python version 3.5 or newer.

Sumo is tested on debian and Fedora linux distributions but should run on all linux distributions. It probably also runs on other flavours of unix, probably even MacOS, but this is not tested.

It may run on windows, escpecially the Cygwin environment, but this is also not tested.

## Install methods

If you just want to give sumo a try without going too much into installation details, you can enter these commands (‘DIRECTORY’ is created by this):

    python -m venv DIRECTORY
    source DIRECTORY/bin/activate
    pip install EPICS-sumo

The sections below describe installation methods in more detail.

### Install with pip

pip is the python package manager. It is easy to use, the only disadvantage is that on Linux systems it circumvents your package manager.

#### Install locations

First you have to check where you want to install sumo:

- globally, which is the default, see global install

- just for the current user, see user install

- at a specific path, see PYTHONUSERBASE

- in a python virtual environment, see virtual environment

#### Install examples (shown for global install)

Install from pypi (easiest when you have an internet connection):

    pip install EPICS-sumo

Install from downloaded *.tar.gz or *.whl file [1]:

    pip install FILENAME

Install from source directory [2]:

    pip install DIRECTORY

[1] (1,2,3)

You can download these files at sumo downloads at Sourceforge

[2]

You can checkout the repository with `hg clone http://hg.code.sf.net/p/epics-sumo/mercurial epics-sumo-mercurial`

### Global install with with system’s package manager (Linux)

On systems with debian package manager (debian/ubuntu/suse…) [1] [3]:

    dpkg -i PACKAGEFILE

On systems with rpm package manager (fedora/RHEL/CentOS…) [1] [4]:

    rpm -ivh PACKAGEFILE

[3]

The *.deb files were created for Debian Linux. They may work for other debian based distributions like ubuntu but this was not tested.

[4]

The *.rpm files were created for Fedora Linux. They may work for other rpm based distributions like RedHat Linux but this was not tested.

## The sumo configuration file

In order to use sumo on your system you should create a configuration file. The default name for this file is “sumo.config”.

See Configuration Files for a complete description of configuration files.

See sumo.config examples for examples of configuration files.

See sumo config new for a command that creates a configuration file from a template provided with sumo.